package XTaTIK::Docs::Appendix::Templates;

use strict;
use warnings;

our $VERSION = '0.005002'; # VERSION

1;
__END__

=encoding utf8

=head1 NAME

XTaTIK::Docs::Appendix::Templates - Map of XTaTIK template files you can override

=head1 YET TO BE WRITTEN

=cut