package XTaTIK::Docs::Appendix::XTaTIK_conf;

use strict;
use warnings;

our $VERSION = '0.005002'; # VERSION

1;
__END__

=encoding utf8

=for stopwords conf _conf XTaTIK_conf

=head1 NAME

XTaTIK::Docs::Appendix::XTaTIK_conf - Explanation of XTaTIK.conf parameters

=head1 YET TO BE WRITTEN

=cut