use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006009
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
Zoffix
Znet
cpan
lib
XTaTIK
Common
Controller
Blog
Cart
Root
Search
User
Docs
01_Installation
02_PreparingCompanySilo
03_PreparingSiteSilo
04_Launch
Appendix
SASSVariables
StaticFiles
Templates
XTaTIK_conf
Model
ProductSearch
Products
Quote
Quotes
Users
XVars
Plugin
PayPal
Utilities
Misc
ToadFarmer
